class DjangoApi {
  getCustomers() {
    const url = '/don_confiao/api/customers/';
    return this.getRequest(url);
  }

  getProducts() {
    const url = '/don_confiao/api/products/';
    return this.getRequest(url);
  }

  getPaymentMethods() {
    const url = '/don_confiao/payment_methods/all/select_format';
    return this.getRequest(url);
  }

  getSummaryPurchase(purchaseId) {
    const url = `/don_confiao/resumen_compra_json/${purchaseId}`;
    return this.getRequest(url);
  }

  getPurchasesForReconciliation() {
    const url = '/don_confiao/purchases/for_reconciliation';
    return this.getRequest(url);
  }

  createPurchase(purchase) {
    const url = '/don_confiao/api/sales/';
    return this.postRequest(url, purchase);
  }

  createReconciliationJar(reconciliation) {
    const url = '/don_confiao/reconciliate_jar';
    return this.postRequest(url, reconciliation);
  }

  getRequest(url) {
    return new Promise ((resolve, reject) => {
      fetch(url)
        .then(response => response.json())
        .then(data => {
          resolve(data);
        })
        .catch(error => {
          reject(error);
        });
    });


  }

  postRequest(url, content) {
    return new Promise((resolve, reject) => {
      fetch(url, {
        method: 'POST',
        headers: {
          'Content-Type': 'application/json',
        },
        body: JSON.stringify(content)
      })
        .then(response => {
          if (!response.ok) {
            reject(new Error(`Error ${response.status}: ${response.statusText}`));
          } else {
            response.json().then(data => {
              if (!data) {
                reject(new Error('La respuesta no es un JSON válido'));
              } else {
                resolve(data);
              }
            });
          }
        })
        .catch(error => reject(error));
    });
  }
}

  export default DjangoApi;
